@@ -1,9 +1,11 @@
 package Perlanet;
 
-use 5.10.0;
+use 5.34.0;
 use strict;
 use warnings;
 
+use feature 'try';
+
 use Moose;
 use namespace::autoclean;
 
@@ -11,13 +13,12 @@ use DateTime::Duration;
 use DateTime;
 use Perlanet::Entry;
 use Perlanet::Feed;
-use Try::Tiny;
 use URI::Fetch;
 use XML::Feed;
 
 use Perlanet::Types;
 
-our $VERSION = '3.2.0';
+our $VERSION = '3.3.0';
 
 with 'MooseX::Traits';
 
@@ -68,6 +69,22 @@ sub _build_cutoff {
   return DateTime->now - shift->cutoff_duration;
 }
 
+has 'spam_regex' => (
+  isa     => 'Maybe[Str]',
+  is      => 'ro',
+  lazy_build => 1,
+);
+
+sub _build_spam_regex {
+  my $self = shift;
+
+  return unless $self->config->{spam_filter};
+
+  my $re = '(' . join('|', @{$self->config->{spam_filter}}) . ')';
+
+  return $re;
+}
+
 has 'entries' => (
   isa => 'Int',
   is  => 'ro',
@@ -238,10 +255,10 @@ sub fetch_feeds {
 
       push @valid_feeds, $feed;
     }
-    catch {
+    catch ($e) {
       warn 'Errors parsing ' . $feed->feed, "\n";
-      warn "$_\n" if defined $_;
-    };
+      warn "$e\n" if defined $e;
+    }
   }
 
   return \@valid_feeds;
@@ -265,7 +282,7 @@ sub select_entries {
 
   my @feed_entries;
   for my $feed (@$feeds) {
-    my @entries = $feed->_xml_feed->entries;
+    my @entries = grep { ! $self->is_spam_entry($_) } $feed->_xml_feed->entries;
 
     for (@entries) {
       # "Fix" entries with no dates
@@ -280,8 +297,8 @@ sub select_entries {
       }
     }
 
-    @entries = @{ $self->sort_entries(\@entries) };
-    @entries = @{ $self->cutoff_entries(\@entries) };
+    @entries = $self->sort_entries(\@entries)->@*;
+    @entries = $self->cutoff_entries(\@entries)->@*;
 
     my $number_of_entries =
       defined $feed->max_entries ? $feed->max_entries
@@ -303,6 +320,33 @@ sub select_entries {
   return \@feed_entries;
 }
 
+=head2 is_spam_entry
+
+Called internally by L</select_entries>.
+Called for each entry in the feed to determine if it is spam.
+Takes a L<Perlanet::Entry> and returns true if the entry is spam.
+If the entry is not spam, it returns false.
+If the C<spam_regex> attribute is not set, this method will
+return false for all entries.
+
+=cut
+
+sub is_spam_entry {
+  my $self = shift;
+  my ($entry) = @_;
+
+  return unless $self->spam_regex;
+
+  my $re = $self->spam_regex;
+  my $title   = $entry->title;
+  my $content = $entry->content;
+
+  return 1 if $title   =~ /$re/;
+  return 1 if $content =~ /$re/;
+
+  return;
+}
+
 =head2 sort_entries
 
 Called internally by L</run> and passed the list of entries from
